# klsframe

[![Generic badge](https://img.shields.io/badge/status-beta-yellow.svg)](https://shields.io/)
[![PyPI - Version](https://img.shields.io/pypi/v/klsframe.svg)](https://pypi.org/project/klsframe)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/klsframe.svg)](https://pypi.org/project/klsframe)
[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)
[![Maintained](https://img.shields.io/badge/Maintained-yes-green.svg)](https://shields.io/)
[![Maintained](https://img.shields.io/badge/power-up!-red.svg)](https://shields.io/)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install klsframe
```

## License

`klsframe` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
